@@ -16,7 +16,7 @@ import signal
 import sys
 import glob
 import modules.commons
-import random
+import secrets
 import curses
 import stat
 import tempfile
@@ -56,6 +56,7 @@ class Installer(object):
         'disk',
         'eject_cdrom',
         'hostname',
+        'insecure_installation',
         'install_linux_esx',
         'linux_flavor',
         'live',
@@ -65,6 +66,7 @@ class Installer(object):
         'packagelist_file',
         'partition_type',
         'partitions',
+        'photon_release_version',
         'network',
         'password',
         'postinstall',
@@ -115,6 +117,12 @@ class Installer(object):
     create, append and validate configuration date - install_config
     """
     def configure(self, install_config, ui_config = None):
+        if install_config and 'insecure_installation' in install_config:
+            insecure_installation = install_config.pop('insecure_installation')
+
+        if install_config and 'photon_release_version' in install_config:
+            photon_release_version = install_config.pop('photon_release_version')
+
         # Initialize logger and cmd first
         if not install_config:
             # UI installation
@@ -133,6 +141,11 @@ class Installer(object):
             config = IsoConfig()
             install_config = curses.wrapper(config.configure, ui_config)
 
+        if 'insecure_installation' in locals():
+            install_config['insecure_installation'] = insecure_installation
+
+        if 'photon_release_version' in locals():
+            install_config['photon_release_version'] = photon_release_version
         self._add_defaults(install_config)
 
         issue = self._check_install_config(install_config)
@@ -204,7 +217,7 @@ class Installer(object):
 
         # define 'hostname' as 'photon-<RANDOM STRING>'
         if "hostname" not in install_config or install_config['hostname'] == "":
-            install_config['hostname'] = 'photon-%12x' % random.randrange(16**12)
+            install_config['hostname'] = 'photon-%12x' % secrets.randbelow(16**12)
 
         # Set password if needed.
         # Installer uses 'shadow_password' and optionally 'password'/'age'
@@ -251,6 +264,9 @@ class Installer(object):
         if 'photon_docker_image' not in install_config:
             install_config['photon_docker_image'] = "photon:latest"
 
+        if 'insecure_installation' not in install_config:
+            install_config['insecure_installation'] = False
+
     def _check_install_config(self, install_config):
         """
         Sanity check of install_config before its execution.
@@ -387,7 +403,7 @@ class Installer(object):
             self._setup_grub()
             self._create_fstab()
         self._execute_modules(modules.commons.POST_INSTALL)
-        self._disable_network_in_chroot()
+        self._deactivate_network_in_chroot()
         self._unmount_all()
 
     def exit_gracefully(self, signal1=None, frame1=None):
@@ -645,8 +661,9 @@ class Installer(object):
             self.exit_gracefully()
 
         # Install filesystem rpm
-        tdnf_cmd = "tdnf install filesystem --installroot {0} --assumeyes -c {1}".format(self.photon_root,
-                        self.tdnf_conf_path)
+        tdnf_cmd = "tdnf install  filesystem --releasever {0} --installroot {1} --assumeyes -c {2}".format(
+                    self.install_config['photon_release_version'], self.photon_root,
+                    self.tdnf_conf_path)
         retval = self.cmd.run(tdnf_cmd)
         if retval != 0:
             retval = self.cmd.run(['docker', 'run',
@@ -784,7 +801,7 @@ class Installer(object):
                 self.logger.error('Error importing module {}'.format(module))
                 continue
 
-            # the module default is disabled
+            # the module default is deactivate
             if not hasattr(mod, 'enabled') or mod.enabled is False:
                 self.logger.info("module {} is not enabled".format(module))
                 continue
@@ -851,6 +868,8 @@ class Installer(object):
                 repo_file.write("baseurl=file://{}\n".format(self.rpm_cache_dir))
                 keepcache = True
             repo_file.write("gpgcheck=0\nenabled=1\n")
+            if self.install_config['insecure_installation']:
+                repo_file.write("sslverify=0\n")
         with open(self.tdnf_conf_path, "w") as conf_file:
             conf_file.writelines([
                 "[main]\n",
@@ -884,8 +903,9 @@ class Installer(object):
         packages_to_install = {}
         total_size = 0
         stderr = None
-        tdnf_cmd = "tdnf install --installroot {0} --assumeyes -c {1} {2}".format(self.photon_root,
-                        self.tdnf_conf_path, " ".join(selected_packages))
+        tdnf_cmd = "tdnf install --releasever {0} --installroot {1} --assumeyes -c {2} {3}".format(
+                    self.install_config['photon_release_version'], self.photon_root,
+                    self.tdnf_conf_path, " ".join(selected_packages))
         self.logger.debug(tdnf_cmd)
 
         # run in shell to do not throw exception if tdnf not found
@@ -963,9 +983,9 @@ class Installer(object):
         if os.path.exists("/etc/resolv.conf"):
             shutil.copy("/etc/resolv.conf", self.photon_root + '/etc/.')
 
-    def _disable_network_in_chroot(self):
+    def _deactivate_network_in_chroot(self):
         """
-        disable network in chroot
+        deactivate network in chroot
         """
         if os.path.exists(self.photon_root + '/etc/resolv.conf'):
             os.remove(self.photon_root + '/etc/resolv.conf')
@@ -1300,4 +1320,3 @@ class Installer(object):
             if os.path.exists(filepath):
                 return filepath
         raise Exception("File {} not found in the following directories {}".format(filename, self.install_config['search_path']))
-
