@@ -29,6 +29,7 @@ class IsoInstaller(object):
         # if not provided - use /RPMS path from photon_media,
         # exit otherwise.
         repo_path = options.repo_path
+        self.insecure_installation = None
 
         with open('/proc/cmdline', 'r') as f:
             kernel_params = shlex.split(f.read().replace('\n', ''))
@@ -42,9 +43,11 @@ class IsoInstaller(object):
                     repo_path = arg[len("repo="):]
             elif arg.startswith("photon.media="):
                 photon_media = arg[len("photon.media="):]
+            elif arg.startswith("insecure_installation="):
+                self.insecure_installation = bool(int(arg[len("insecure_installation="):]))
 
         if photon_media:
-            self.mount_media(photon_media)
+            self.media_mount_path = self.mount_media(photon_media)
 
         if not repo_path:
             if self.media_mount_path:
@@ -54,7 +57,18 @@ class IsoInstaller(object):
                 return
 
         if ks_path:
-            install_config=self._load_ks_config(ks_path)
+            install_config = self._load_ks_config(ks_path)
+
+
+        # insecure_installation flag added through commandline overrides that of ks_config
+        if self.insecure_installation:
+            if not install_config:
+                install_config = {}
+            install_config['insecure_installation'] = self.insecure_installation
+
+        if not install_config:
+            install_config = {}
+        install_config['photon_release_version'] = options.photon_release_version
 
         if options.ui_config_file:
             ui_config = (JsonWrapper(options.ui_config_file)).read()
@@ -77,7 +91,12 @@ class IsoInstaller(object):
 
     def _load_ks_config(self, path):
         """kick start configuration"""
-        if path.startswith("http://"):
+
+        if path.startswith("http://") and not self.insecure_installation:
+            raise Exception("Refusing to download kick start configuration from non-https URLs. \
+                            \nPass insecure_installation=1 as a parameter when giving http url in ks.")
+
+        if path.startswith("https://") or path.startswith("http://"):
             # Do 5 trials to get the kick start
             # TODO: make sure the installer run after network is up
             ks_file_error = "Failed to get the kickstart file at {0}".format(path)
@@ -85,16 +104,16 @@ class IsoInstaller(object):
             for _ in range(0, 5):
                 err_msg = ""
                 try:
-                    response = requests.get(path, timeout=3)
-                    if response.ok:
-                        return json.loads(response.text)
-                    err_msg = response.text
+                    if self.insecure_installation:
+                        response = requests.get(path, timeout=3, verify=False)
+                    else:
+                        response = requests.get(path, timeout=3, verify=True)
                 except Exception as e:
                     err_msg = e
+                else:
+                    return json.loads(response.text)
 
-                print(ks_file_error)
-                print("error msg: {0}".format(err_msg))
-                print("retry in a second")
+                print("error msg: {0}  Retry after {1} seconds".format(err_msg, wait))
                 time.sleep(wait)
                 wait = wait * 2
 
@@ -108,16 +127,20 @@ class IsoInstaller(object):
                 path = os.path.join(self.media_mount_path, path.replace("cdrom:/", "", 1))
             elif not path.startswith("/"):
                 path = os.path.join(os.getcwd(), path)
+            elif len(path.split(':')) == 2:
+                ks_path_split = path.split(':')
+                ks_mounted_path = self.mount_media(ks_path_split[0], mount_path='/mnt/ks')
+                if ks_path_split[1].startswith("/"):
+                    ks_path_split[1] = ks_path_split[1][1:]
+                path = os.path.join(ks_mounted_path, ks_path_split[1])
+            else:
+                raise Exception("Kickstart file provided is not in correct format.")
             return (JsonWrapper(path)).read()
 
-    def mount_media(self, photon_media):
-        """Mount the cd with RPMS"""
-        # check if the cd is already mounted
-        if self.media_mount_path:
-            return
-        mount_path = "/mnt/media"
+    def mount_media(self, photon_media, mount_path="/mnt/media"):
+        """Mount the external media"""
 
-        # Mount the cd to get the RPMS
+        # Make the mounted directories
         os.makedirs(mount_path, exist_ok=True)
 
         # Construct mount cmdline
@@ -129,8 +152,8 @@ class IsoInstaller(object):
         elif photon_media == "cdrom":
             cmdline.append('/dev/cdrom')
         else:
-            print("Unsupported installer media, check photon.media in kernel cmdline")
-            raise Exception("Can not mount the cd")
+            #User specified mount path
+            cmdline.append(photon_media)
 
         cmdline.extend(['-o', 'ro', mount_path])
 
@@ -139,13 +162,12 @@ class IsoInstaller(object):
             process = subprocess.Popen(cmdline)
             retval = process.wait()
             if retval == 0:
-                self.media_mount_path = mount_path
-                return
-            print("Failed to mount the cd, retry in a second")
+                return mount_path
+            print("Failed to mount the device, retry in a second")
             time.sleep(1)
-        print("Failed to mount the cd, exiting the installer")
+        print("Failed to mount the device, exiting the installer")
         print("check the logs for more details")
-        raise Exception("Can not mount the cd")
+        raise Exception("Can not mount the device")
 
 
 if __name__ == '__main__':
